@@ -816,6 +816,7 @@ void RequestPrivate::refreshAccessToken() {
     
     QUrl tokenUrl(TOKEN_URL);
     QNetworkRequest request(tokenUrl);
+    request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
     QString body("client_id=" + clientId + "&client_secret=" + clientSecret + "&refresh_token=" + refreshToken +
                  "&grant_type=" + GRANT_TYPE_REFRESH);
                     
@@ -837,8 +838,8 @@ void RequestPrivate::_q_onAccessTokenRefreshed() {
     bool ok;
     setResult(QtJson::Json::parse(reply->readAll(), ok));
     
-    QNetworkReply::NetworkError e = reply->error();
-    QString es = reply->errorString();
+    const QNetworkReply::NetworkError e = reply->error();
+    const QString es = reply->errorString();
     reply->deleteLater();
     reply = 0;
     
@@ -920,11 +921,11 @@ void RequestPrivate::_q_onReplyFinished() {
     }
     
     bool ok = true;
-    QString response = QString::fromUtf8(reply->readAll());
+    const QString response = QString::fromUtf8(reply->readAll());
     setResult(response.isEmpty() ? response : QtJson::Json::parse(response, ok));
     
-    QNetworkReply::NetworkError e = reply->error();
-    QString es = reply->errorString();
+    const QNetworkReply::NetworkError e = reply->error();
+    const QString es = reply->errorString();
     reply->deleteLater();
     reply = 0;
     
